@@ -273,9 +273,9 @@ void MiscControlPage::SetControlsOnLaunch()
 	m_powerButton->Enable(true);
 	m_resetButton->Enable(true);
 	m_pauseButton->Enable(true);
-	m_printerportSelector->Enable(true);
 	m_pauseButton->SetValue(false);
 	m_firmwareButton->SetValue(false);
+	m_printerportSelector->Enable(true);
 	m_printerLogFile->Enable(true);
 	m_browsePrinterLog->Enable(true);
 	m_printerportFileLabel->Enable(true);
@@ -393,6 +393,10 @@ void MiscControlPage::OnInputMaxFrameskip(wxCommandEvent& event)
 
 void MiscControlPage::InitConnectorPanel()
 {
+	// first disable them all, for cases where we don't have that whole connector present
+	FindWindowByName(wxT("PrinterportSelector"))->Enable(false);
+	FindWindowByName(wxT("Joyport1Selector"))->Enable(false);
+	FindWindowByName(wxT("Joyport2Selector"))->Enable(false);
 	for (auto& connector : m_controller.GetConnectors()) {
 		wxString currentClass = m_controller.GetConnectorClass(connector);
 		if (connector == wxT("joyporta")) {
@@ -411,6 +415,7 @@ void MiscControlPage::InitJoystickOrPrinterPort(wxString connector, wxString con
 	if (classes.IsEmpty()) return;
 
 	auto* box = (wxComboBox*)FindWindowByName(control);
+	box->Enable(true);
 	wxString currentval = box->GetValue();
 	box->Clear();
 	box->Append(wxT("--empty--"));
@@ -421,13 +426,21 @@ void MiscControlPage::InitJoystickOrPrinterPort(wxString connector, wxString con
 			box->Append(pluggables[i]);
 		}
 	}
-	if (box->FindString(currentval) == wxNOT_FOUND) {
-		currentval = box->GetString(0);
-	}
-	box->SetValue(currentval);
-	wxString cmd = wxT("plug");
-	if (currentval != wxT("--empty--")) {
-		m_controller.WriteCommand(cmd + wxT(" ") + connector + wxT(" ") + currentval);
+	if (m_controller.IsRelaunching()) {
+		// if relaunching, then just update the values
+		wxString currentlyPlugged = m_controller.GetConnectorPlugged(connector);
+		box->SetValue(currentlyPlugged.IsEmpty() ? wxT("--empty--") : currentlyPlugged);
+	} else {
+		// Initializing (initial launch)
+		if (box->FindString(currentval) == wxNOT_FOUND) {
+			currentval = box->GetString(0);
+		}
+		box->SetValue(currentval);
+		if (currentval != wxT("--empty--")) {
+			m_controller.WriteCommand(wxT("plug ") + connector + wxT(" ") + currentval);
+		} else {
+			m_controller.WriteCommand(wxT("unplug ") + connector);
+		}
 	}
 }
 
@@ -481,23 +494,23 @@ void MiscControlPage::OnJoystickChanged()
 		cmd = wxT("plug ");
 	}
 
-	bool flag1=false;
-	if (box->GetValue() != wxT("--empty--")){
-		assert(box2!=0);
-		if(!box2)throw "box2 must not be null, but it is null.";
+	bool sameDevicePluggedInTwoPorts = false;
+	if (box->GetValue() != wxT("--empty--")) {
+		assert(box2 != 0);
+		if (!box2) throw "box2 must not be null, but it is null.";
 
-		if(box->GetValue() == box2->GetValue()){
-			flag1=true;
-			assert(oldValue1!=0);
-			if(!oldValue1)throw "oldValue1 must not be null, but it is null.";
+		if (box->GetValue() == box2->GetValue()) {
+			sameDevicePluggedInTwoPorts = true;
+			assert(oldValue1 != 0);
+			if (!oldValue1) throw "oldValue1 must not be null, but it is null.";
 			MessageActive = true;
 			int result = wxMessageBox(wxT("Unable to plug a device in more than one port!\n\nDo you still want to plug it into this port?\nThis device will then be removed from any other port(s)."),
 				wxT("Warning"),
 				wxOK | wxCANCEL);
 			MessageActive = false;
 			if (result == wxOK) {
-				assert(oldValue2!=0);
-				if(!oldValue2)throw "oldValue2 must not be null, but it is null.";
+				assert(oldValue2 != 0);
+				if (!oldValue2) throw "oldValue2 must not be null, but it is null.";
 
 				box2->SetSelection(0);
 				*oldValue2 = wxT("--empty--");
@@ -510,7 +523,7 @@ void MiscControlPage::OnJoystickChanged()
 			}
 		}
 	}
-	if(!flag1){
+	if (!sameDevicePluggedInTwoPorts) {
 		// no collision
 		m_controller.WriteCommand(cmd + connector + value);
 		assert(oldValue1!=0);
@@ -522,7 +535,6 @@ void MiscControlPage::OnJoystickChanged()
 	ConfigurationData::instance().SetParameter(ConfigurationData::CD_JOYPORT1, joy1->GetValue());
 	ConfigurationData::instance().SetParameter(ConfigurationData::CD_JOYPORT2, joy2->GetValue());
 	ConfigurationData::instance().SaveData();
-
 }
 
 void MiscControlPage::OnChangeRenShaTurbo(wxScrollEvent& event)
