@@ -44,6 +44,7 @@ openMSXController::openMSXController(wxWindow* target)
 	m_openMSXID = 0;
 	m_appWindow = (wxCatapultFrame*)target;
 	m_openMsxRunning = false;
+	m_isRelaunching = false;
 	InitLaunchScript();
 }
 
@@ -158,12 +159,6 @@ void openMSXController::HandleParsedOutput(wxCommandEvent& event)
 				UpdateSetting2(data->name, data->contents);
 				ExecuteStart(m_relaunch); // reinit stuff now
 			}
-		} else if (data->updateType == CatapultXMLParser::UPDATE_UNPLUG) {
-			if ((lastCmd[0] != wxT("unplug")) ||
-			    (lastCmd[1] != data->name)) {
-				UpdateSetting2(data->name, data->contents);
-				ExecuteStart(m_relaunch); // reinit stuff now
-			}
 		} else if (data->updateType == CatapultXMLParser::UPDATE_HARDWARE) {
 			ExecuteStart(m_relaunch); // reinit stuff now
 		} else if (data->updateType == CatapultXMLParser::UPDATE_EXTENSION) {
@@ -485,7 +480,6 @@ void openMSXController::InitLaunchScript()
 			m_appWindow->m_sessionPage->SetCassetteMode(info.Last());
 		});
 	AddCommand(wxT("openmsx_update enable plug"));
-	AddCommand(wxT("openmsx_update enable unplug"));
 	AddCommand(wxT("openmsx_update enable connector"));
 	AddCommand(wxT("openmsx_update enable hardware"));
 	AddCommand(wxT("openmsx_update enable extension"));
@@ -493,6 +487,7 @@ void openMSXController::InitLaunchScript()
 	AddCommand(wxT(""), // finish launch
 		[&](const wxString&, const wxString&) {
 			m_appWindow->OpenMSXStarted();
+			m_isRelaunching = false;
 		});
 
 	AddSetting(wxT("renderer"),
@@ -658,6 +653,11 @@ void openMSXController::AddSetting(
 
 void openMSXController::ExecuteStart(int startLine)
 {
+	if (m_isRelaunching && (startLine > 0)) {
+		// Canceling relaunch, already relaunching
+		return;
+	}
+	m_isRelaunching = (startLine > 0);
 	sendStep = startLine;
 	ExecuteNext();
 }
@@ -666,13 +666,13 @@ void openMSXController::ExecuteNext()
 {
 	WriteCommand(m_launchScript[sendStep].command,
 		[&](const wxString& c, const wxString& r) {
-			HandleLauch(c, r, true); },
+			HandleLaunch(c, r, true); },
 		[&](const wxString& c, const wxString& r) {
-			HandleLauch(c, r, false); });
+			HandleLaunch(c, r, false); });
 	m_launchCallback.push_back(m_launchScript[sendStep].callback);
 }
 
-void openMSXController::HandleLauch(const wxString& command, const wxString& result, bool ok)
+void openMSXController::HandleLaunch(const wxString& command, const wxString& result, bool ok)
 {
 	// Handle received command
 	assert(!m_launchCallback.empty());
